Literature
==========

Below is a list of references that are cited in the documentation of
``pylibtemplate``, namely on this page: [RefLabel1]_ and [RefLabel2]_.

.. [RefLabel1] |nbspc|"Characterizing Topological Order by Studying the Ground
	       States on an Infinite Cylinder" L. Cincio, G. Vidal, Phys. Rev.
	       Lett. 110, 067208 (2013), :arxiv:`1208.2623`
	       :doi:`10.1103/PhysRevLett.110.067208`
.. [RefLabel2] |nbspc|"Detection of symmetry-protected topological phases in
	       one dimension" F. Pollmann, A. Turner, Phys. Rev. B 86, 125441
	       (2012), :arxiv:`1204.0704` :doi:`10.1103/PhysRevB.86.125441`

.. |nbspc| unicode:: U+00A0 .. non-breaking space
